# discord-cal

Publish your status on discord using data from an iCal calendar over a rich presence.

## Installation and usage

```bash
pip install discord-cal
```

```bash
discord-cal -i <app_id> -c <calendar_id>
```

If you would like details, include the `-d` flag.
